@@ -1,6 +1,6 @@
 from Form import *
 from Table import *
-from Module import *
+from ModuleHandler import *
 
 NOTE_INFORMATION = 'Which information should be shown.'
 
@@ -10,18 +10,22 @@ options = [
     ('connection_details', "Server Information + Connections")
 ]
 
-class ModuleServerInfo (Module, FormHelper):
+HELPS = [
+    ('modules_handlers_server_info', "Server Information")
+]
+
+class ModuleServerInfo (ModuleHandler):
     PROPERTIES = []
 
     def __init__ (self, cfg, prefix, submit_url):
-        Module.__init__ (self, 'server_info', cfg, prefix, submit_url)
-        FormHelper.__init__ (self, 'server_info', cfg)
+        ModuleHandler.__init__ (self, 'server_info', cfg, prefix, submit_url)
+        self.show_document_root = False
 
     def _op_render (self):
         txt  = "<h2>Privacy settings</h2>"
 
         table = TableProps()
-        self.AddPropOptions (table, "Show Information", 
+        self.AddPropOptions_Reload (table, "Show Information",
                              "%s!type" % (self._prefix),
                              options, NOTE_INFORMATION)
         txt += self.Indent(table)
